@@ -1,7 +1,7 @@
 package Bencher::Scenario::DateTimeFormatAlami::Parsing;
 
-our $DATE = '2016-06-29'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DATE = '2016-06-30'; # DATE
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,8 +10,8 @@ use warnings;
 our $scenario = {
     summary => 'Benchmark parsing speed of DateTime::Format::Alami against some other modules',
     modules => {
-        'DateTime::Format::Alami::EN' => {version => 0.11},
-        'DateTime::Format::Alami::ID' => {version => 0.11},
+        'DateTime::Format::Alami::EN' => {version => 0.13},
+        'DateTime::Format::Alami::ID' => {version => 0.13},
     },
     participants => [
         {
@@ -42,6 +42,8 @@ our $scenario = {
     ],
     datasets => [
         {args => {text => '18 feb'}},
+        {args => {text => '18 feb 2011'}},
+        {args => {text => '18 feb 2011 06:30:45'}},
         {args => {text => 'today'}, include_participant_tags => ['lang:en']},
         {args => {text => 'hari ini'}, include_participant_tags => ['lang:id']},
     ],
@@ -62,7 +64,7 @@ Bencher::Scenario::DateTimeFormatAlami::Parsing - Benchmark parsing speed of Dat
 
 =head1 VERSION
 
-This document describes version 0.003 of Bencher::Scenario::DateTimeFormatAlami::Parsing (from Perl distribution Bencher-Scenarios-DateTimeFormatAlami), released on 2016-06-29.
+This document describes version 0.004 of Bencher::Scenario::DateTimeFormatAlami::Parsing (from Perl distribution Bencher-Scenarios-DateTimeFormatAlami), released on 2016-06-30.
 
 =head1 SYNOPSIS
 
@@ -82,9 +84,9 @@ Version numbers shown below are the versions used when running the sample benchm
 
 L<Date::Extract> 0.05
 
-L<DateTime::Format::Alami::EN> 0.11
+L<DateTime::Format::Alami::EN> 0.13
 
-L<DateTime::Format::Alami::ID> 0.11
+L<DateTime::Format::Alami::ID> 0.13
 
 L<DateTime::Format::Flexible> 0.26
 
@@ -142,6 +144,10 @@ Code template:
 
 =item * 18 feb
 
+=item * 18 feb 2011
+
+=item * 18 feb 2011 06:30:45
+
 =item * today
 
 =item * hari ini
@@ -155,34 +161,73 @@ Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (
 Benchmark with default options (C<< bencher -m DateTimeFormatAlami::Parsing >>):
 
  #table1#
- +-----------------------------+----------+-----------+-----------+------------+---------+---------+
- | participant                 | dataset  | rate (/s) | time (ms) | vs_slowest |  errors | samples |
- +-----------------------------+----------+-----------+-----------+------------+---------+---------+
- | DateTime::Format::Flexible  | today    |       350 |     2.9   |       1    | 2.1e-05 |      20 |
- | DateTime::Format::Flexible  | 18 feb   |       350 |     2.8   |       1    | 2.4e-05 |      21 |
- | Date::Extract               | 18 feb   |       679 |     1.47  |       1.94 | 7.5e-07 |      20 |
- | Date::Extract               | today    |       926 |     1.08  |       2.65 | 6.2e-07 |      21 |
- | DateTime::Format::Natural   | 18 feb   |      1210 |     0.825 |       3.47 | 6.4e-07 |      20 |
- | DateTime::Format::Alami::EN | 18 feb   |      1300 |     0.77  |       3.7  | 2.5e-06 |      20 |
- | DateTime::Format::Alami::ID | 18 feb   |      1300 |     0.768 |       3.73 | 6.2e-07 |      21 |
- | DateTime::Format::Natural   | today    |      2300 |     0.44  |       6.5  | 4.8e-07 |      20 |
- | DateTime::Format::Alami::EN | today    |      3500 |     0.29  |      10    |   6e-07 |      23 |
- | DateTime::Format::Alami::ID | hari ini |     22000 |     0.045 |      64    | 6.7e-08 |      20 |
- +-----------------------------+----------+-----------+-----------+------------+---------+---------+
+ {dataset=>"18 feb"}
+ +-----------------------------+-----------+-----------+------------+---------+---------+
+ | participant                 | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +-----------------------------+-----------+-----------+------------+---------+---------+
+ | DateTime::Format::Flexible  |       330 |     3     |       1    | 2.9e-05 |      21 |
+ | Date::Extract               |       750 |     1.33  |       2.25 | 4.1e-07 |      22 |
+ | DateTime::Format::Alami::EN |       940 |     1.1   |       2.8  | 1.7e-06 |      21 |
+ | DateTime::Format::Alami::ID |      1420 |     0.704 |       4.27 | 6.4e-07 |      20 |
+ | DateTime::Format::Natural   |      1460 |     0.683 |       4.4  | 4.3e-07 |      20 |
+ +-----------------------------+-----------+-----------+------------+---------+---------+
+
+ #table2#
+ {dataset=>"18 feb 2011"}
+ +-----------------------------+-----------+-----------+------------+---------+---------+
+ | participant                 | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +-----------------------------+-----------+-----------+------------+---------+---------+
+ | Date::Extract               |       148 |      6.76 |       1    | 2.5e-06 |      20 |
+ | DateTime::Format::Natural   |       166 |      6.02 |       1.12 | 1.8e-06 |      20 |
+ | DateTime::Format::Alami::EN |       370 |      2.71 |       2.5  | 1.4e-06 |      20 |
+ | DateTime::Format::Flexible  |       370 |      2.7  |       2.5  | 1.5e-05 |      20 |
+ | DateTime::Format::Alami::ID |       622 |      1.61 |       4.21 |   1e-06 |      23 |
+ +-----------------------------+-----------+-----------+------------+---------+---------+
+
+ #table3#
+ {dataset=>"18 feb 2011 06:30:45"}
+ +-----------------------------+-----------+-----------+------------+---------+---------+
+ | participant                 | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +-----------------------------+-----------+-----------+------------+---------+---------+
+ | Date::Extract               |       149 |     6.7   |       1    | 2.7e-06 |      20 |
+ | DateTime::Format::Flexible  |       370 |     2.7   |       2.5  |   2e-05 |      21 |
+ | DateTime::Format::Natural   |      1020 |     0.983 |       6.82 | 6.9e-07 |      20 |
+ | DateTime::Format::Alami::EN |      1300 |     0.75  |       9    | 3.8e-06 |      20 |
+ | DateTime::Format::Alami::ID |      1380 |     0.727 |       9.22 | 4.7e-07 |      21 |
+ +-----------------------------+-----------+-----------+------------+---------+---------+
+
+ #table4#
+ {dataset=>"hari ini"}
+ +-----------------------------+----------+------+-----------+-----------+------------+---------+---------+
+ | participant                 | dataset  | perl | rate (/s) | time (μs) | vs_slowest |  errors | samples |
+ +-----------------------------+----------+------+-----------+-----------+------------+---------+---------+
+ | DateTime::Format::Alami::ID | hari ini | perl |      3400 |       300 |          1 | 4.8e-07 |      20 |
+ +-----------------------------+----------+------+-----------+-----------+------------+---------+---------+
+
+ #table5#
+ {dataset=>"today"}
+ +-----------------------------+-----------+-----------+------------+---------+---------+
+ | participant                 | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +-----------------------------+-----------+-----------+------------+---------+---------+
+ | DateTime::Format::Flexible  |       370 |     2.7   |       1    | 9.6e-06 |      22 |
+ | Date::Extract               |       979 |     1.02  |       2.61 | 9.1e-07 |      20 |
+ | DateTime::Format::Natural   |      2600 |     0.385 |       6.93 | 2.7e-07 |      20 |
+ | DateTime::Format::Alami::EN |      3300 |     0.3   |       8.8  | 4.1e-07 |      22 |
+ +-----------------------------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m DateTimeFormatAlami::Parsing --module-startup >>):
 
- #table1#
+ #table6#
  +-----------------------------+-----------+------------------------+------------+-----------+---------+
  | participant                 | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
  +-----------------------------+-----------+------------------------+------------+-----------+---------+
- | DateTime::Format::Flexible  |     110   |                  105.4 |        1   |   0.00015 |      20 |
- | Date::Extract               |      90   |                   85.4 |        1   |   0.0012  |      21 |
- | DateTime::Format::Natural   |      85   |                   80.4 |        1.3 |   0.00066 |      20 |
- | DateTime::Format::Alami::ID |      23   |                   18.4 |        4.9 | 5.8e-05   |      21 |
- | DateTime::Format::Alami::EN |      22   |                   17.4 |        5   | 4.8e-05   |      20 |
- | perl -e1 (baseline)         |       4.6 |                    0   |       24   | 3.5e-05   |      21 |
+ | DateTime::Format::Flexible  |     120   |                  115.6 |        1   |   0.0011  |      21 |
+ | Date::Extract               |      86   |                   81.6 |        1.4 |   0.00072 |      20 |
+ | DateTime::Format::Natural   |      82   |                   77.6 |        1.5 |   0.00036 |      20 |
+ | DateTime::Format::Alami::ID |      25   |                   20.6 |        4.9 |   0.00017 |      20 |
+ | DateTime::Format::Alami::EN |      23   |                   18.6 |        5.2 | 6.2e-05   |      21 |
+ | perl -e1 (baseline)         |       4.4 |                    0   |       27   | 1.2e-05   |      20 |
  +-----------------------------+-----------+------------------------+------------+-----------+---------+
 
 =head1 DESCRIPTION
